@@ -1,7 +1,7 @@
 /*
  * tio - a simple TTY terminal I/O application
  *
- * Copyright (c) 2014-2016  Martin Lund
+ * Copyright (c) 2014-2017  Martin Lund
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,13 +23,18 @@
 #define TTY_H
 
 #define KEY_QUESTION 0x3f
+#define KEY_B 0x62
 #define KEY_C 0x63
+#define KEY_H 0x68
 #define KEY_L 0x6C
 #define KEY_Q 0x71
 #define KEY_S 0x73
 #define KEY_T 0x74
 #define KEY_CTRL_T 0x14
 
+#define NORMAL 0
+#define HEX 1
+
 void stdout_configure(void);
 void stdout_restore(void);
 void tty_configure(void);
